#ifndef DLL_IFC_INCLUDED
#define DLL_IFC_INCLUDED

#include "stddef.h"

// for malloc/free on Linux/Windows
#if !defined(GHS_ARM_BIOS)
#include "stdlib.h"
#endif


#ifdef __cplusplus


// functions that can be used in the dll
extern "C"
{
void  dll_debug    (char *file, int line);
void *dll_malloc_ex(char *path, int line, size_t size, int align_size=8, int heap=1, unsigned flags=0);
void  dll_free     (char *path, int line, void *p);
}


// the dll interface itself
class C_Dll
{
	public:

	typedef struct t_version
	{
		char major;
		char minor;
		char build;
		char reserved;
	} t_version;

	friend class C_DllIfc;
	private:

	virtual char      *Date() { return __DATE__; };
	virtual char      *Time() { return __TIME__; };

	virtual bool       Init();
	virtual char      *Name()    = 0;
	virtual t_version  Version() = 0;

	protected:

	C_Dll();
	virtual ~C_Dll();

	public:

#if defined(OS_WIN)
	#define DLL_EXPORT __declspec(dllexport)
#else
	#define DLL_EXPORT
#endif

#if defined(GHS_ARM_BIOS)
	void *operator new(size_t n)
	{
		return dll_malloc_ex(__FILE__,__LINE__,n);
	}

	void operator delete( void *p)
	{
		dll_free(__FILE__,__LINE__,p);
	}
#else
	void *operator new(size_t n)
	{
		return malloc(n);
	}

	void operator delete( void *p)
	{
		free(p);
	}
#endif

	#define DLL_IFC_VERSION 0x00000003

	static DLL_EXPORT C_Dll* Get(unsigned &IfcVersion);
};


class C_Exe : public C_Dll
{
	friend class C_DllIfc;

#define EXE_MAGIC 0x27082008
	private:
	unsigned m_magic;

	public:
	C_Exe();
	virtual ~C_Exe();

	virtual int main(int argc, char *argv[]) = 0;
};


#endif // __cplusplus

#endif // DLL_IFC_INCLUDED
