#ifndef SYSLOG2_H_INCLUDED
#define SYSLOG2_H_INCLUDED

// This is the Syslog2 application api

#include "vcsIntTypes.h"
#include "orig_auth.h"


// Syslog Severity levels RFC 5424
#define SLS_EMERGENCY 0  //Emergency:     system is unusable
#define SLS_ALERT     1  //Alert:         action must be taken immediately
#define SLS_CRITICAL  2  //Critical:      critical conditions
#define SLS_ERROR     3  //Error:         error conditions
#define SLS_WARNING   4  //Warning:       warning conditions
#define SLS_NOTICE    5  //Notice:        normal but significant condition
#define SLS_INFO      6  //Informational: informational messages
#define SLS_DEBUG     7  //Debug:         debug-level messages


// Syslog Facility IDs  RFC 5424
#define SLF_KERNEL    ( 0 << 3)
#define SLF_USER      ( 1 << 3)
#define SLF_MAIL      ( 2 << 3)
#define SLF_DAEMON    ( 3 << 3)
#define SLF_SECURITY  ( 4 << 3)
#define SLF_SYSLOG    ( 5 << 3)
#define SLF_PRINTER   ( 6 << 3)
#define SLF_NETWORK   ( 7 << 3)
#define SLF_UUCP      ( 8 << 3)   // Remote execution
#define SLF_CLOCK     ( 9 << 3)
#define SLF_SECURITY2 (10 << 3)
#define SLF_FTP       (11 << 3)
#define SLF_NTP       (12 << 3)
#define SLF_AUDIT     (13 << 3)
#define SLF_ALERT     (14 << 3)
#define SLF_CLOCK2    (15 << 3)
#define SLF_LOCAL0    (16 << 3)   // FixMe define values for this
#define SLF_LOCAL1    (17 << 3)
#define SLF_LOCAL2    (18 << 3)
#define SLF_LOCAL3    (19 << 3)
#define SLF_LOCAL4    (20 << 3)
#define SLF_LOCAL5    (21 << 3)
#define SLF_LOCAL6    (22 << 3)
#define SLF_LOCAL7    (23 << 3)

#define MAX_SYSLOG_MSG_LEN 480  // RFC 5424   480 min supported len; 2048 max supported len
#define MAX_SYSLOG_MOD_NAME_LEN 32
#define MAX_SYSLOG_URL_LEN 42
#define MAX_SYSLOG_DATE_LEN 40
#define MAX_MODUL_ITEMS 512
#define UNKNOWN_MODUL_ID  MAX_MODUL_ITEMS  // this is never returned by the DB


// #define VTN_CONFIGURATION "config_sync"   // Virtual Task name for the Config Sysnc
#define VTN_SYSLOG        "syslog"
#define VTN_MIN_MAX_STATS "system_stats"

// Task Groups Accordig list from KS
#define VTN_SYSTEM        "system"
#define VTN_USER_MGMT     "user_mgmt"
#define VTN_STORAGE       "storage"
#define VTN_RECORDING     "recording"
#define VTN_OPERATION     "operation"
#define VTN_CONFIG        "configuration"
#define VTN_IMAGE_PIPE    "image_pipe"
#define VTN_SYSTEM_CONTR      "system_contr" // External enduser-logs
#define VTN_SYSTEM_CONTR_ASA  "sc_asa_rep"   // Internal ASA-Report file

#define VTN_COMISSIONING  "commissioning"
#define VTN_BLUETOOTH     "bluetooth"
#define VTN_CONFIG_INTERN "config_intern"

    // ^^ New ids must be registered by g_TaskNameToFacility[]



#ifdef __cplusplus
  extern "C" {
#endif



// Common application logging api
void Syslog(int Priority, const char *ModulName, const struct t_OrigAuthInfo *pOrigAuthInfo, const char* format, ...);

// like Syslog() but does drop events during bootup (e.g. values changed by restore-config)

void SyslogSilentBoot(int Priority, const char *ModulName, const struct t_OrigAuthInfo *pOrigAuthInfo, const char* format, ...);

void SyslogVPrint(int Priority, const char *ModulName, const struct t_OrigAuthInfo *pOrigAuthInfo, const char *format, va_list ap);

// Do only(!!!)use once before reboot or on crash
void SyslogForceFlush(void);

// For the config service only
void syslog_config_entry_changed(DWORD ConfigId, DWORD log_groups, const char *CustomMessage, void *pConfEntry, DWORD EntrySize, const struct t_OrigAuthInfo *pOrigAuthInfo);


// For the RCP server only
struct RCP_Pending_Request;

void syslog_rcp_command(struct RCP_Pending_Request	*RCP_Request);

void SyslogReportFileChanges(const char *pFileName);

void SyslogUpdateConfigSealingEnabled(BOOL Val, DWORD ConfigSealingDateTime, DWORD SealingRandom);
int BuildConfigSealingStatusMessage(OCTET *pBuff, int BuffSize, OCTET Status, DWORD TimeSealed, DWORD SealingRandom);
BOOL SyslogSealBrokenPending(void);


#ifdef __cplusplus
  }
#endif



#endif // SYSLOG2_H_INCLUDED

