/*
 * vcsIntTypes.h: common data types
 *
 * Copyright 2003 VCS AG
 *
 * History:
 * 2003-11-25 Bernd Anh�upl, VCS AG
 *            initial version
 * 2004-02-03 Bernd Anh�upl, VCS AG
 *            generic support for non-TriMedia platforms
 * 2004-03-26 Bernd Anh�upl, VCS AG
 *            don't use signed types for TMS320C6X platforms
 * 2004-05-28 Bernd Anh�upl, VCS AG
 *            renamed _vcsTypes_h to _vcsIntTypes_h for 
 *            compatibility with vcsTypes.h which now includes
 *            only this file
 * 2014-05-16 include stdint.h if possible
 *            and derive our types from there
 *            + remove old/unused stuff
 * 2015-08-13 remove own std type definition fallback for
 *            visual studio <2010 which did not have stdint.h
 */

#ifndef _vcsIntTypes_h
#define _vcsIntTypes_h


// obtain the standard types from stdint.h
#include <stdint.h>
#include <stddef.h>   // size_t on GHS and TI



#ifdef _MSC_VER 		/* to avoid trouble with Windows' own typedefs... */
#  define DWORD vcsDWORD
#  define WORD  vcsWORD
#  define OCTET vcsOCTET
#  define BOOL  vcsBOOL
#endif


#ifndef TRUE
#  define TRUE 1
#endif

#ifndef FALSE
#  define FALSE 0
#endif

typedef uint32_t  DWORD;
typedef uint16_t  WORD;
typedef uint8_t   OCTET;
typedef int32_t   BOOL;

typedef uint32_t  UInt32;
typedef uint16_t  UInt16;
typedef uint8_t   UInt8;
typedef int32_t   Int32;
typedef int16_t   Int16;
#if defined (HW_TI_NETRA)
typedef char      Int8;		// TI has several .h files where Int8 is typedef'd as 'char' and not 'signed char'
#else
typedef int8_t    Int8;
#endif

typedef uint64_t  Void64;

typedef int       flag_t;

typedef uint32_t  BITFIELD_DWORD;
typedef uint16_t  BITFIELD_WORD;
typedef uint8_t   BITFIELD_OCTET;


#ifndef INLINE
#	ifdef __cplusplus
#		define INLINE inline
#	else
#		if defined(_MSC_VER) //Microsoft compiler
#			define INLINE __inline
#		elif defined(__ghs__) //Green Hills compiler: "__inline" means for C89/C99 also "static"
#			define INLINE __inline
#		elif defined(__TI_COMPILER_VERSION__) //TI compiler
#			define INLINE inline
#		elif defined(__GNUC__) //GNU C/C++ compiler
#			define INLINE __inline__
#		else
#			error INLINE is not defined for this compiler.
#		endif
#	endif
#endif


#endif
